.. _spkg_httpcore:

httpcore: Minimal low-level HTTP client
=======================================

Description
-----------

Minimal low-level HTTP client

License
-------

Upstream Contact
----------------

https://pypi.org/project/httpcore/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_certifi`
- :ref:`spkg_h11`
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    1.0.9

version_requirements.txt::

    httpcore

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install httpcore

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i httpcore


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
